==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/ElasticBeanstalk/ListAvailableSolutionStacks.pm <==

package Paws::ElasticBeanstalk::ListAvailableSolutionStacks {
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListAvailableSolutionStacks');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ElasticBeanstalk::ListAvailableSolutionStacksResultMessage');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'ListAvailableSolutionStacksResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::ListAvailableSolutionStacks - Arguments for method ListAvailableSolutionStacks on Paws::ElasticBeanstalk

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListAvailableSolutionStacks on the 
AWS Elastic Beanstalk service. Use the attributes of this class
as arguments to method ListAvailableSolutionStacks.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to ListAvailableSolutionStacks.

As an example:

  $service_obj->ListAvailableSolutionStacks(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for ListAvailableSolutionStacks in Paws::ElasticBeanstalk

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.05.tar.gz: Paws-0.05/lib/Paws/ElasticBeanstalk/ListAvailableSolutionStacks.pm <==

package Paws::ElasticBeanstalk::ListAvailableSolutionStacks {
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListAvailableSolutionStacks');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ElasticBeanstalk::ListAvailableSolutionStacksResultMessage');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'ListAvailableSolutionStacksResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::ElasticBeanstalk::ListAvailableSolutionStacks - Arguments for method ListAvailableSolutionStacks on Paws::ElasticBeanstalk

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListAvailableSolutionStacks on the 
AWS Elastic Beanstalk service. Use the attributes of this class
as arguments to method ListAvailableSolutionStacks.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to ListAvailableSolutionStacks.

As an example:

  $service_obj->ListAvailableSolutionStacks(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListAvailableSolutionStacks in L<Paws::ElasticBeanstalk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
